adjust_focus_for_user_select

Function adjust_focus_for_user_select 

pub(crate) fn adjust_focus_for_user_select(
    no_gc: &NoGC,
    anchor: Option<&RootedSelectionBoundary>,
    focus_candidate: RootedSelectionBoundary,
    user_select_contain_node_for_anchor: Option<&Node>,
) -> RootedSelectionBoundary
Adjust the range boundary for the selection focus (end of a drag gesture) based on user-select of the container node and of its ancestors.